==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/gu.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "લાઇટબૉક્સ ગેલેરી પરિમાણો વ્યવસ્થા");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "ગેલેરી મેનેજ");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "પૂર્ણ કદ ઇમેજ પહોળાઈ");
define('MANAGE_GALLERY_FULL_HEIGHT', "પૂર્ણ કદ ઇમેજ ઊંચાઈ");
define('MANAGE_GALLERY_THUMB_WIDTH', "થંબનેલ છબી પહોળાઈ");
define('MANAGE_GALLERY_THUMB_HEIGHT', "થંબનેલ છબી ઊંચાઈ");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "જાળવો અંગૂઠો પાસા ગુણોત્તર");
define('MANAGE_GALLERY_SHOW_TITLES', "બતાવો શિર્ષકો");
define('MANAGE_GALLERY_DISABLE_SORT', "અક્ષમ કરો સૉર્ટ");
define('MANAGE_GALLERY_DELETE_IMAGE', "છબી કાઢી નાખો");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "સૉર્ટ ક્રમ સાચવો");
define('MANAGE_GALLERY_PUBLISH_MSG', "પ્રકાશિત કરવા માટે ક્લિક કરો &#39;સુધારા&#39; <br /> તમારી અપલોડ કરેલી છબીઓ.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "બધા છબીઓ પુન: માપ કરવામાં આવી છે અને ગોઠવણીઓ સંગ્રહ કરવામાં આવી છે.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "માપ બદલવાની છબીઓ અથવા સેટિંગ્સ સાચવવામાં એક ભૂલ આવી હતી.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "તમારી છબી (ઓ) અપલોડ કરવામાં આવી છે.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "તમારી છબી (ઓ) અપલોડ કરતી વખતે ભૂલ આવી હતી.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "ફાઇલ તમે અપલોડ કરવાનો પ્રયાસ કરવામાં આવે એક છબી નથી.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "ફાઇલ તમે અપલોડ કરવાનો પ્રયાસ કરવામાં આવે ખૂબ મોટી છે.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "શીર્ષક સાચવવામાં આવી છે.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "તમે ખાતરી કરો કે તમે ઇમેજ કાઢી નાખવા માંગો છો");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "છબી ભૂંસી દેવાયું છે.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "છબી કાઢી નાખવામાં ભૂલ આવી હતી.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "પરિમાણો સાચવી અને માપ બદલવાની છબીઓ, કૃપા કરીને રાહ જુઓ ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "અપલોડ કરી, કૃપા કરીને રાહ જુઓ ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "સૉર્ટ ક્રમ સંગ્રહ કરવામાં આવી છે. તમે સૉર્ટ ક્રમ સેવ કરવા માંગો છો?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "છબી સૉર્ટ ક્રમ સાચવવામાં આવી છે.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "છબી સૉર્ટ બચત એક ભૂલ આવી હતી.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/gu.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "લાઇટબૉક્સ ગેલેરી પરિમાણો વ્યવસ્થા");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "ગેલેરી મેનેજ");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "પૂર્ણ કદ ઇમેજ પહોળાઈ");
define('MANAGE_GALLERY_FULL_HEIGHT', "પૂર્ણ કદ ઇમેજ ઊંચાઈ");
define('MANAGE_GALLERY_THUMB_WIDTH', "થંબનેલ છબી પહોળાઈ");
define('MANAGE_GALLERY_THUMB_HEIGHT', "થંબનેલ છબી ઊંચાઈ");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "જાળવો અંગૂઠો પાસા ગુણોત્તર");
define('MANAGE_GALLERY_SHOW_TITLES', "બતાવો શિર્ષકો");
define('MANAGE_GALLERY_DISABLE_SORT', "અક્ષમ કરો સૉર્ટ");
define('MANAGE_GALLERY_DELETE_IMAGE', "છબી કાઢી નાખો");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "સૉર્ટ ક્રમ સાચવો");
define('MANAGE_GALLERY_PUBLISH_MSG', "પ્રકાશિત કરવા માટે ક્લિક કરો &#39;સુધારા&#39; <br /> તમારી અપલોડ કરેલી છબીઓ.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "બધા છબીઓ પુન: માપ કરવામાં આવી છે અને ગોઠવણીઓ સંગ્રહ કરવામાં આવી છે.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "માપ બદલવાની છબીઓ અથવા સેટિંગ્સ સાચવવામાં એક ભૂલ આવી હતી.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "તમારી છબી (ઓ) અપલોડ કરવામાં આવી છે.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "તમારી છબી (ઓ) અપલોડ કરતી વખતે ભૂલ આવી હતી.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "ફાઇલ તમે અપલોડ કરવાનો પ્રયાસ કરવામાં આવે એક છબી નથી.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "ફાઇલ તમે અપલોડ કરવાનો પ્રયાસ કરવામાં આવે ખૂબ મોટી છે.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "શીર્ષક સાચવવામાં આવી છે.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "તમે ખાતરી કરો કે તમે ઇમેજ કાઢી નાખવા માંગો છો");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "છબી ભૂંસી દેવાયું છે.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "છબી કાઢી નાખવામાં ભૂલ આવી હતી.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "પરિમાણો સાચવી અને માપ બદલવાની છબીઓ, કૃપા કરીને રાહ જુઓ ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "અપલોડ કરી, કૃપા કરીને રાહ જુઓ ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "સૉર્ટ ક્રમ સંગ્રહ કરવામાં આવી છે. તમે સૉર્ટ ક્રમ સેવ કરવા માંગો છો?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "છબી સૉર્ટ ક્રમ સાચવવામાં આવી છે.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "છબી સૉર્ટ બચત એક ભૂલ આવી હતી.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "તમે અપલોડ કરવાનો પ્રયાસ કરી રહ્યાં છો તે ફાઇલ &#39;અપલોડ_મેક્સ_ફાઇઝલાઇઝ&#39; અથવા &#39;પોસ્ટ_મેક્સ_સાઇઝ&#39; PHP સેટિંગ્સ કરતા મોટી છે. આ મર્યાદાઓ વધારવા માટે તમારા સિસ્ટમ સંચાલકનો સંપર્ક કરો.");
?>
